@@ -127,6 +127,7 @@ static void test_strline(void)
 	"t=0 0\r\n" \
 	"m=audio 16006 RTP/AVP 97\r\n" \
 	"a=rtpmap:97 GSM-EFR/8000\r\n" \
+	"a=fmtp:126 0/1/2\r\n" \
 	"a=ptime:40\r\n"
 
 #define MDCX4_ADDR0000 \
@@ -335,6 +336,7 @@ static void test_strline(void)
 	"t=0 0\r\n" \
 	"m=audio 16006 RTP/AVP 97\r\n" \
 	"a=rtpmap:97 GSM-EFR/8000\r\n" \
+	"a=fmtp:126 0/1/2\r\n" \
 	"a=ptime:40\r\n"
 
 #define CRCX_ZYN \
@@ -386,56 +388,6 @@ static void test_strline(void)
 	"a=rtpmap:97 GSM-EFR/8000\r\n" \
 	"a=ptime:40\r\n"
 
-#define CRCX_PORT_0 \
-	"CRCX 3 1@mgw MGCP 1.0\r\n" \
-	"m: recvonly\r\n" \
-	"C: 2\r\n" \
-	"L: p:20\r\n" \
-	"\r\n" \
-	"v=0\r\n" \
-	"c=IN IP4 123.12.12.123\r\n" \
-	"m=audio 0 RTP/AVP 97\r\n" \
-	"a=rtpmap:97 GSM-EFR/8000\r\n" \
-	"a=ptime:40\r\n"
-
-#define CRCX_PORT_0_RET \
-	"200 3 OK\r\n" \
-	"I: %s\r\n" \
-	"\r\n" \
-	"v=0\r\n" \
-	"o=- %s 23 IN IP4 0.0.0.0\r\n" \
-	"s=-\r\n" \
-	"c=IN IP4 0.0.0.0\r\n" \
-	"t=0 0\r\n" \
-	"m=audio 16014 RTP/AVP 97\r\n" \
-	"a=rtpmap:97 GSM-EFR/8000\r\n" \
-	"a=ptime:40\r\n"
-
-#define CRCX_PORT_0_IUFP \
-	"CRCX 4 1@mgw MGCP 1.0\r\n" \
-	"m: recvonly\r\n" \
-	"C: 2\r\n" \
-	"L: p:20\r\n" \
-	"\r\n" \
-	"v=0\r\n" \
-	"c=IN IP4 123.12.12.123\r\n" \
-	"m=audio 0 RTP/AVP 96\r\n" \
-	"a=rtpmap:96 VND.3GPP.IUFP/16000\r\n" \
-	"a=ptime:40\r\n"
-
-#define CRCX_PORT_0_IUFP_RET \
-	"200 4 OK\r\n" \
-	"I: %s\r\n" \
-	"\r\n" \
-	"v=0\r\n" \
-	"o=- %s 23 IN IP4 0.0.0.0\r\n" \
-	"s=-\r\n" \
-	"c=IN IP4 0.0.0.0\r\n" \
-	"t=0 0\r\n" \
-	"m=audio 16016 RTP/AVP 96\r\n" \
-	"a=rtpmap:96 VND.3GPP.IUFP/16000\r\n" \
-	"a=ptime:40\r\n"
-
 #define DLCX \
 	"DLCX 7 1@mgw MGCP 1.0\r\n" \
 	"I: %s\r\n" \
@@ -634,6 +586,7 @@ struct mgcp_test {
 	const char *req;
 	const char *exp_resp;
 	int ptype;
+	const char *extra_fmtp;
 };
 
 static const struct mgcp_test tests[] = {
@@ -661,9 +614,10 @@ static const struct mgcp_test tests[] = {
 	{"RQNT1", RQNT, RQNT1_RET},
 	{"RQNT2", RQNT2, RQNT2_RET},
 	{"DLCX", DLCX, DLCX_RET, PTYPE_IGNORE},
-	{"CRCX", CRCX, CRCX_FMTP_RET, 97},
-	{"MDCX3", MDCX3, MDCX3_FMTP_RET, PTYPE_NONE},
-	{"DLCX", DLCX, DLCX_RET, PTYPE_IGNORE},
+	{"CRCX", CRCX, CRCX_FMTP_RET, 97,.extra_fmtp = "a=fmtp:126 0/1/2"},
+	{"MDCX3", MDCX3, MDCX3_FMTP_RET, PTYPE_NONE,.extra_fmtp =
+	 "a=fmtp:126 0/1/2"},
+	{"DLCX", DLCX, DLCX_RET, PTYPE_IGNORE,.extra_fmtp = "a=fmtp:126 0/1/2"},
 	{"CRCX", CRCX_NO_LCO_NO_SDP, CRCX_NO_LCO_NO_SDP_RET, 97},
 	{"CRCX", CRCX_X_OSMO_IGN, CRCX_X_OSMO_IGN_RET, 97},
 	{"MDCX_TOO_LONG_CI", MDCX_TOO_LONG_CI, MDCX_TOO_LONG_CI_RET},
@@ -673,8 +627,6 @@ static const struct mgcp_test tests[] = {
 	{"MDCX_NULL", MDCX_NULL, MDCX_NULL_RET},
 	{"DLCX_NULL", DLCX_NULL, DLCX_NULL_RET},
 	{"RQNT_NULL", RQNT_NULL, RQNT_NULL_RET},
-	{"CRCX_PORT_0", CRCX_PORT_0, CRCX_PORT_0_RET, 97},
-	{"CRCX_PORT_0_IUFP", CRCX_PORT_0_IUFP, CRCX_PORT_0_IUFP_RET, 96},
 };
 
 static const struct mgcp_test retransmit[] = {
@@ -705,13 +657,12 @@ static struct msgb *create_msg(const char *str, const char *conn_id)
 
 static int dummy_packets = 0;
 /* override and forward */
-int osmo_iofd_sendto_msgb(struct osmo_io_fd *iofd, struct msgb *msg, int flags, const struct osmo_sockaddr *addr)
+ssize_t sendto(int sockfd, const void *buf, size_t len, int flags,
+	       const struct sockaddr *dest_addr, socklen_t addrlen)
 {
 	uint32_t dest_host =
-	    htonl(((struct sockaddr_in *)addr)->sin_addr.s_addr);
-	int dest_port = htons(((struct sockaddr_in *)addr)->sin_port);
-	const uint8_t *buf = msgb_data(msg);
-	size_t len = msgb_length(msg);
+	    htonl(((struct sockaddr_in *)dest_addr)->sin_addr.s_addr);
+	int dest_port = htons(((struct sockaddr_in *)dest_addr)->sin_port);
 
 	if (len == sizeof(rtp_dummy_payload)
 	    && memcmp(buf, rtp_dummy_payload, sizeof(rtp_dummy_payload)) == 0) {
@@ -725,8 +676,6 @@ int osmo_iofd_sendto_msgb(struct osmo_io_fd *iofd, struct msgb *msg, int flags,
 	OSMO_ASSERT(dest_host);
 	OSMO_ASSERT(dest_port);
 
-	msgb_free(msg);
-
 	return len;
 }
 
@@ -882,6 +831,9 @@ static void test_messages(void)
 
 		dummy_packets = 0;
 
+		osmo_talloc_replace_string(cfg, &trunk->audio_fmtp_extra,
+					   t->extra_fmtp);
+
 		inp = create_msg(t->req, last_conn_id);
 		msg = mgcp_handle_message(cfg, inp);
 		msgb_free(inp);
@@ -2192,7 +2144,7 @@ static bool codec_decision(struct mgcp_conn_rtp *conn, unsigned int index_conn_s
 static void test_mgcp_codec_decide(void)
 {
 	int i;
-	bool ok_all = true;
+	bool ok = true;
 	printf("\nTesting mgcp_codec_find_convertible()\n");
 
 	for (i = 0; i < ARRAY_SIZE(test_mgcp_codec_find_convertible_cases); i++) {
@@ -2201,7 +2153,6 @@ static void test_mgcp_codec_decide(void)
 		int rc;
 		int conn_i;
 		int c;
-		bool ok = true;
 
 		printf("#%d: %s\n", i, t->descr);
 
@@ -2242,12 +2193,9 @@ static void test_mgcp_codec_decide(void)
 			printf(" ===> SUCCESS: codec decision as expected!\n");
 		else
 			printf(" ===> FAIL: unexpected codec decision!\n");
-
-		if (!ok)
-			ok_all = false;
 	}
 
-	OSMO_ASSERT(ok_all);
+	OSMO_ASSERT(ok);
 }
 
 void test_conn_id_matching(void)
